Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

[Unreleased]
============

[0.2.0] - 2023-22-03
====================

Changed
-------

 - Moved to Plugin Manager 2
 - Anaconda deployement workflow


[0.1.0] - 2022-28-07
====================

Added
-----

 - Empty plugin template
 - template.plugin archive
 - add README with explanations
